@@ -1,7 +1,7 @@
 import pandas as pd
 
 
-def rsi(df, price="close", col="rsi", n):
+def rsi(df,n, price="close", col="rsi"):
     """
     The Relative Strength Index (RSI) is a momentum indicator that measures the
     magnitude of recent price changes to evaluate overbought or oversold
