@@ -1,6 +1,6 @@
-def ohlcv(df,col,n=1):
+def ohlcv(df,col,n):
 
 	df = df.copy()
 	df = df[['datetime',col]]
 
-	return df.tail(n)
\ No newline at end of file
+	return df.tail()
\ No newline at end of file
