@@ -1,5 +1,5 @@
 import pandas as pd
-def donchian_channel(df, high="high", low="low", col="dc", n):
+def donchian_channel(df, n, high="high", low="low", col="dc"):
     """Calculate donchian channel of given pandas data frame.
     :param df: pandas.DataFrame
     :param n:
