@@ -8,7 +8,7 @@ from voyant_indicators.overlapping_studies.dema import dema
 from voyant_indicators.overlapping_studies.tema import tema
 
 
-def macd(df, price="close", col="macd", fast_period, slow_period, signal_period):
+def macd(df, fast_period, slow_period, signal_period, price="close", col="macd"):
     """
     The Moving Average Convergence Divergence (MACD) is the difference between
     two Exponential Moving Averages. The Signal line is an Exponential Moving
