@@ -9,7 +9,7 @@ from voyant_indicators.overlapping_studies.dema import dema
 from voyant_indicators.overlapping_studies.tema import tema
 
 
-def t3(df, price, col="t3", n, v_factor=0.7):
+def t3(df, price, n, col="t3", v_factor=0.7):
     """
     The T3 is a type of moving average, or smoothing function. It is based on the
     DEMA. The T3 takes the DEMA calculation and adds a vfactor which is between
