@@ -1,6 +1,6 @@
 import pandas as pd
 
-def fi(df,close, volume, col, n=2):
+def fi(df,close="close", volume="volume", col="fi", n=2):
     """Force Index (FI)
     It illustrates how strong the actual buying or selling pressure is. High
     positive values mean there is a strong rising trend, and low values signify
